package cn.com.infosec.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.nist.NISTObjectIdentifiers;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.RSASSAPSSparams;
import cn.com.infosec.asn1.teletrust.TeleTrusTObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x9.X9ObjectIdentifiers;
import cn.com.infosec.jce.X509Principal;
import cn.com.infosec.util.Strings;
import java.io.IOException;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.PrivateKey;
import java.security.Provider;
import java.security.SecureRandom;
import java.security.Security;
import java.security.Signature;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Set;
import javax.security.auth.x500.X500Principal;

class X509Util {
   private static Hashtable algorithms = new Hashtable();
   private static Hashtable params = new Hashtable();
   private static Set noParams = new HashSet();

   static {
      DERObjectIdentifier var0 = PKCSObjectIdentifiers.md2WithRSAEncryption;
      algorithms.put("MD2WITHRSAENCRYPTION", var0);
      algorithms.put("MD2WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.md5WithRSAEncryption;
      algorithms.put("MD5WITHRSAENCRYPTION", var0);
      algorithms.put("MD5WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.sha1WithRSAEncryption;
      algorithms.put("SHA1WITHRSAENCRYPTION", var0);
      algorithms.put("SHA1WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.sha224WithRSAEncryption;
      algorithms.put("SHA224WITHRSAENCRYPTION", var0);
      algorithms.put("SHA224WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.sha256WithRSAEncryption;
      algorithms.put("SHA256WITHRSAENCRYPTION", var0);
      algorithms.put("SHA256WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.sha384WithRSAEncryption;
      algorithms.put("SHA384WITHRSAENCRYPTION", var0);
      algorithms.put("SHA384WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.sha512WithRSAEncryption;
      algorithms.put("SHA512WITHRSAENCRYPTION", var0);
      algorithms.put("SHA512WITHRSA", var0);
      var0 = PKCSObjectIdentifiers.id_RSASSA_PSS;
      algorithms.put("SHA1WITHRSAANDMGF1", var0);
      algorithms.put("SHA224WITHRSAANDMGF1", var0);
      algorithms.put("SHA256WITHRSAANDMGF1", var0);
      algorithms.put("SHA384WITHRSAANDMGF1", var0);
      algorithms.put("SHA512WITHRSAANDMGF1", var0);
      var0 = TeleTrusTObjectIdentifiers.rsaSignatureWithripemd160;
      algorithms.put("RIPEMD160WITHRSAENCRYPTION", var0);
      algorithms.put("RIPEMD160WITHRSA", var0);
      var0 = TeleTrusTObjectIdentifiers.rsaSignatureWithripemd128;
      algorithms.put("RIPEMD128WITHRSAENCRYPTION", var0);
      algorithms.put("RIPEMD128WITHRSA", var0);
      var0 = TeleTrusTObjectIdentifiers.rsaSignatureWithripemd256;
      algorithms.put("RIPEMD256WITHRSAENCRYPTION", var0);
      algorithms.put("RIPEMD256WITHRSA", var0);
      var0 = X9ObjectIdentifiers.id_dsa_with_sha1;
      algorithms.put("SHA1WITHDSA", var0);
      algorithms.put("DSAWITHSHA1", var0);
      DERObjectIdentifier var1 = NISTObjectIdentifiers.dsa_with_sha224;
      algorithms.put("SHA224WITHDSA", var1);
      DERObjectIdentifier var2 = NISTObjectIdentifiers.dsa_with_sha256;
      algorithms.put("SHA256WITHDSA", var2);
      DERObjectIdentifier var3 = X9ObjectIdentifiers.ecdsa_with_SHA1;
      algorithms.put("SHA1WITHECDSA", var3);
      algorithms.put("ECDSAWITHSHA1", var3);
      DERObjectIdentifier var4 = X9ObjectIdentifiers.ecdsa_with_SHA224;
      algorithms.put("SHA224WITHECDSA", var4);
      DERObjectIdentifier var5 = X9ObjectIdentifiers.ecdsa_with_SHA256;
      algorithms.put("SHA256WITHECDSA", var5);
      DERObjectIdentifier var6 = X9ObjectIdentifiers.ecdsa_with_SHA384;
      algorithms.put("SHA384WITHECDSA", var6);
      DERObjectIdentifier var7 = X9ObjectIdentifiers.ecdsa_with_SHA512;
      algorithms.put("SHA512WITHECDSA", var7);
      DERObjectIdentifier var8 = CryptoProObjectIdentifiers.gostR3411_94_with_gostR3410_94;
      algorithms.put("GOST3411WITHGOST3410", var8);
      algorithms.put("GOST3411WITHGOST3410-94", var8);
      DERObjectIdentifier var9 = CryptoProObjectIdentifiers.gostR3411_94_with_gostR3410_2001;
      algorithms.put("GOST3411WITHECGOST3410", var9);
      algorithms.put("GOST3411WITHECGOST3410-2001", var9);
      algorithms.put("GOST3411WITHGOST3410-2001", var9);
      noParams.add(var3);
      noParams.add(var4);
      noParams.add(var5);
      noParams.add(var6);
      noParams.add(var7);
      noParams.add(var0);
      noParams.add(var1);
      noParams.add(var2);
      noParams.add(var8);
      noParams.add(var9);
      AlgorithmIdentifier var10;
      var10 = new AlgorithmIdentifier.<init>(OIWObjectIdentifiers.idSHA1, new DERNull());
      params.put("SHA1WITHRSAANDMGF1", creatPSSParams(var10, 20));
      var10 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha224, new DERNull());
      params.put("SHA224WITHRSAANDMGF1", creatPSSParams(var10, 28));
      var10 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha256, new DERNull());
      params.put("SHA256WITHRSAANDMGF1", creatPSSParams(var10, 32));
      var10 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha384, new DERNull());
      params.put("SHA384WITHRSAANDMGF1", creatPSSParams(var10, 48));
      var10 = new AlgorithmIdentifier.<init>(NISTObjectIdentifiers.id_sha512, new DERNull());
      params.put("SHA512WITHRSAANDMGF1", creatPSSParams(var10, 64));
   }

   private static RSASSAPSSparams creatPSSParams(AlgorithmIdentifier hashAlgId, int saltSize) {
      AlgorithmIdentifier var10002 = hashAlgId;
      AlgorithmIdentifier var2;
      var2 = new AlgorithmIdentifier.<init>(PKCSObjectIdentifiers.id_mgf1, hashAlgId);
      DERInteger hashAlgId1;
      hashAlgId1 = new DERInteger.<init>(saltSize);
      DERInteger saltSize1;
      saltSize1 = new DERInteger.<init>(1);
      return new RSASSAPSSparams(var10002, var2, hashAlgId1, saltSize1);
   }

   static DERObjectIdentifier getAlgorithmOID(String algorithmName) {
      algorithmName = Strings.toUpperCase(algorithmName);
      return algorithms.containsKey(algorithmName) ? (DERObjectIdentifier)algorithms.get(algorithmName) : new DERObjectIdentifier(algorithmName);
   }

   static AlgorithmIdentifier getSigAlgID(DERObjectIdentifier sigOid, String algorithmName) {
      if (noParams.contains(sigOid)) {
         return new AlgorithmIdentifier(sigOid);
      } else {
         algorithmName = Strings.toUpperCase(algorithmName);
         if (params.containsKey(algorithmName)) {
            return new AlgorithmIdentifier(sigOid, (DEREncodable)params.get(algorithmName));
         } else {
            DERNull algorithmName1;
            algorithmName1 = new DERNull.<init>();
            return new AlgorithmIdentifier(sigOid, algorithmName1);
         }
      }
   }

   static Iterator getAlgNames() {
      Enumeration var0 = algorithms.keys();
      ArrayList var1;
      var1 = new ArrayList.<init>();

      while(var0.hasMoreElements()) {
         var1.add(var0.nextElement());
      }

      return var1.iterator();
   }

   static Signature getSignatureInstance(String algorithm) {
      return Signature.getInstance(algorithm);
   }

   static Signature getSignatureInstance(String algorithm, String provider) {
      return provider != null ? Signature.getInstance(algorithm, provider) : Signature.getInstance(algorithm);
   }

   static byte[] calculateSignature(DERObjectIdentifier sigOid, String sigName, PrivateKey key, SecureRandom random, ASN1Encodable object) {
      if (sigOid != null) {
         Signature sigOid1 = getSignatureInstance(sigName);
         if (random != null) {
            sigOid1.initSign(key, random);
         } else {
            sigOid1.initSign(key);
         }

         sigOid1.update(object.getEncoded("DER"));
         return sigOid1.sign();
      } else {
         throw new IllegalStateException("no signature algorithm specified");
      }
   }

   static byte[] calculateSignature(DERObjectIdentifier sigOid, String sigName, String provider, PrivateKey key, SecureRandom random, ASN1Encodable object) {
      if (sigOid != null) {
         Signature sigOid1 = getSignatureInstance(sigName, provider);
         if (random != null) {
            sigOid1.initSign(key, random);
         } else {
            sigOid1.initSign(key);
         }

         sigOid1.update(object.getEncoded("DER"));
         return sigOid1.sign();
      } else {
         throw new IllegalStateException("no signature algorithm specified");
      }
   }

   static X509Principal convertPrincipal(X500Principal principal) {
      try {
         return new X509Principal(principal.getEncoded());
      } catch (IOException var1) {
         throw new IllegalArgumentException("cannot convert principal");
      }
   }

   static Implementation getImplementation(String baseName, String algorithm, Provider prov) {
      String var3;
      for(algorithm = Strings.toUpperCase(algorithm); (var3 = prov.getProperty("Alg.Alias." + baseName + "." + algorithm)) != null; algorithm = var3) {
      }

      if ((baseName = prov.getProperty(baseName + "." + algorithm)) != null) {
         ClassLoader var10000;
         boolean var10001;
         try {
            var10000 = prov.getClass().getClassLoader();
         } catch (ClassNotFoundException var10) {
            var10001 = false;
            throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but no class \"" + baseName + "\" found!");
         } catch (Exception var11) {
            var10001 = false;
            throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but class \"" + baseName + "\" inaccessible!");
         }

         ClassLoader var12 = var10000;
         Class var14;
         if (var10000 != null) {
            try {
               var14 = var12.loadClass(baseName);
            } catch (ClassNotFoundException var8) {
               var10001 = false;
               throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but no class \"" + baseName + "\" found!");
            } catch (Exception var9) {
               var10001 = false;
               throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but class \"" + baseName + "\" inaccessible!");
            }
         } else {
            try {
               var14 = Class.forName(baseName);
            } catch (ClassNotFoundException var6) {
               var10001 = false;
               throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but no class \"" + baseName + "\" found!");
            } catch (Exception var7) {
               var10001 = false;
               throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but class \"" + baseName + "\" inaccessible!");
            }
         }

         Class var13 = var14;

         try {
            return new Implementation(var13.newInstance(), prov);
         } catch (ClassNotFoundException var4) {
            var10001 = false;
            throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but no class \"" + baseName + "\" found!");
         } catch (Exception var5) {
            var10001 = false;
            throw new IllegalStateException("algorithm " + algorithm + " in provider " + prov.getName() + " but class \"" + baseName + "\" inaccessible!");
         }
      } else {
         throw new NoSuchAlgorithmException("cannot find implementation " + algorithm + " for provider " + prov.getName());
      }
   }

   static Implementation getImplementation(String baseName, String algorithm) {
      Provider[] var2 = Security.getProviders();

      for(int var3 = 0; var3 != var2.length; ++var3) {
         String var4 = Strings.toUpperCase(algorithm);
         Implementation var6;
         if ((var6 = getImplementation(baseName, var4, var2[var3])) != null) {
            return var6;
         }

         try {
            getImplementation(baseName, algorithm, var2[var3]);
         } catch (NoSuchAlgorithmException var5) {
         }
      }

      throw new NoSuchAlgorithmException("cannot find implementation " + algorithm);
   }

   static Provider getProvider(String provider) {
      Provider var1;
      if ((var1 = Security.getProvider(provider)) != null) {
         return var1;
      } else {
         throw new NoSuchProviderException("Provider " + provider + " not found");
      }
   }

   static class Implementation {
      Object engine;
      Provider provider;

      Implementation(Object engine, Provider provider) {
         this.engine = engine;
         this.provider = provider;
      }

      Object getEngine() {
         return this.engine;
      }

      Provider getProvider() {
         return this.provider;
      }
   }
}
